def func_a(_):
    func_b()


def func_b():
    func_c()


def func_c():
    func_d()


def func_d():
    raise Exception("Guessing time !")


def bad_syntax():
    import badsyntax
    badsyntax


def bad_module():
    import badmodule
    badmodule



import pickle
import sys

import pytest
import six

from tblib import pickling_support  # noqa: E402

pytest.importorskip('twisted')


def test_30():
    from twisted.python.failure import Failure

    pickling_support.install()

    try:
        raise ValueError
    except ValueError:
        s = pickle.dumps(sys.exc_info())

    f = None
    try:
        six.reraise(*pickle.loads(s))
    except ValueError:
        f = Failure()

    assert f is not None
